function AMSR2_3km_to_PNG_S(SDtime,PTO)
% =======================================================================
%
% AMSR2_3km_to_PNG.m produces a PNG image for the Ross Sea region, 
%   from AMSR2 3.125 km images.
%
% Presently set to hard-code data directory for input file, and various
%   other switches
%
%
%  Laurie Padman, ESR (padman@esr.org)
%  Susan Howard,  ESR (showard@esr.org)
%
% =======================================================================
SLAT=71; SLON=0; HEMI='s';            % Polar stereo chocies
ax=[-600 500 -1700 -1100];dx=1; nd=1; % Ross Sea continental shelf
lats=[-80:1:-70];                     % values for grid overlay
lons=[-175:5:180];
% Specify where to find 
fileloc='.\DATA\AMSR2_3km\';
% Set output resolution pres (dpi), colormap axis limits (cax) and color
%   for lat/lon grid overlay
pres1=450; pres2=60;
cax=[0 100]; gridcol=0.5*[1 1 1];
fig=20;
%========================================================================

%addpath('D:\Projects\Antarctic_seaice\AMSR2_3.125\LP_prod');

A2=read_amsr2_S(SDtime,fileloc);
% disp(['Processing AMSR2 3 km for ' datestr(SDtime)]);

X=A2.x(1:nd:end); Y=A2.y(1:nd:end); M=A2.seaice(1:nd:end,1:nd:end);
[X2d,Y2d]=meshgrid(X,Y);

% bathymetry
 RT=load('D:\Projects\Antarctic_seaice\Script_data_files\RTOPO2\RTOPO2_ANT.mat');
%RT=load('E:\Projects\Antarctic_DEM\RTOPO2\RTOPO2_ANT.mat');
xg=ax(1):dx:ax(2); yg=ax(3):dx:ax(4);
[xg,yg]=meshgrid(xg,yg);                [rg,cg]=size(xg);
[latg,long]=mapxy(xg,yg,SLAT,SLON,HEMI);
hg=interp2(RT.lon,RT.lat,RT.sbd',long,latg);

% Mask: SM.mask=1 for land, =2 for ice shelves
load D:\Projects\Antarctic_seaice\Script_data_files\scripps_mask\SCRIPPS_MASK_2012.mat

figure(fig); clf; 
% cmap=gray(256); cmap=flipud(cmap(128:256,:));
% load E:\Projects\SeaIce\scripts\ice_conc_cmap.mat; 
load amsr2_cmap_BGW.mat;
colormap(cmap);
[x2d,y2d]=meshgrid(X,Y);
[lat2d,lon2d]=mapxy(xg,yg,SLAT,SLON,HEMI);

% Mask land and ice shelves
whos
mask=interp2(SM.x,SM.y,SM.mask,X2d,Y2d,'nearest');
M(mask>0)=NaN;
pcolor(X,Y,M); shading interp;
hold on
plot_moa(1,'k',SLAT,SLON,HEMI);
contour(xg,yg,lat2d,lats,'color',gridcol,'LineWidth',0.3);
contour(xg,yg,lon2d,lons,'color',gridcol,'LineWidth',0.3);
contour(xg,yg,hg,[-1500 -1000 -500],'r','LineWidth',0.3);
axis('equal'); axis(ax);
caxis(cax); 
set(gca,'LineWidth',1);
title(['AMSR-2 3 km, ' datestr(SDtime)],'interpreter','none');

% lat/lon labels around edges
% right side
lat1=latg(1,end); lat2=latg(end,end);
loc=find(lats>lat2 & lats<lat1);
for i=1:length(loc);
    LAT=lats(loc(i));
    [dum,ind]=min(abs(latg(:,end)-LAT));
    str=[num2str(-LAT) '^oS'];
    ht=text(ax(2),yg(ind,end),str); hold on
    set(ht,'color','k')
end

% left side
lat1=latg(1,1); lat2=latg(end,1);
loc=find(lats>lat2 & lats<lat1);
for i=1:length(loc);
    LAT=lats(loc(i));
    [dum,ind]=min(abs(latg(:,1)-LAT));
    str=[num2str(-LAT) '^oS'];
    ht=text(ax(1),yg(ind,1),str); hold on
    set(ht,'color','k','HorizontalALignment','right')
end

% bottom
for i=1:length(lons);
    LON=lons(i); ix=1:cg;
    [dum,ind]=min(abs(long(1,:)-LON));
    if(ind<1 | ind>cg); break; end
    if(xg(1,ind)>ax(1) & xg(1,ind)<ax(2));
        str=[num2str(LON) '^o'];
        ht=text(xg(1,ind),ax(3),str); hold on
        set(ht,'color','k','HorizontalALignment','center',...
            'VerticalAlignment','top');
    end
end

set(gca,'XTick',[],'YTick',[]);

% Add float locations
% floats=xlsread('D:\Projects\Antarctic_seaice\MODIS\LP_prod\Floats\ALAMO_float_locations_v3.csv',...
%     'A3:I11');
%floats=xlsread('ALAMO_float_locations_v3.csv',...
%    'A3:I11');
%[F.x,F.y]=mapll(floats(:,9),floats(:,8),SLAT,SLON,HEMI);
% for i=1:length(F.x);
%     % if(floats(i,1)<10); col='r'; elseif(floats(i,1)>=10); col='b'; end
%     plot(F.x(i),F.y(i),'o','color','r','LineWidth',1,...
%         'MarkerFaceColor','g'); hold on
%     ht=text(F.x(i)+10,F.y(i),num2str(floats(i,1))); hold on
%     set(ht,'color','r','Rotation',0,'FontSize',10)
% end

floats=xlsread('D:\Projects\Antarctic_seaice\Script_data_files\Floats\ALAMO_2016\ALAMO_Deployments.xlsx',...
     'A5:H10');
F.lat=floats(:,5); F.lon=floats(:,6); F.id=floats(:,2);
[F.x,F.y]=mapll(F.lat,F.lon,SLAT,SLON,HEMI);
for i=1:length(F.x);
    plot(F.x(i),F.y(i),'o','color','y','LineWidth',1.5,...
        'MarkerFaceColor','r'); hold on
    if(i==1 | i==4)
        ht=text(F.x(i)-10,F.y(i),num2str(F.id(i)),...
            'HorizontalAlignment','right'); hold on
    else
        ht=text(F.x(i)+10,F.y(i),num2str(F.id(i))); hold on
    end
    set(ht,'color','y','Rotation',0,'FontSize',8)
end
 



% disp([num2str(min(min(M))) ' ' num2str(max(max(M)))]);
hc=colorbar;
set(gca,'Position',[0.10 0.10 0.75 0.80]);
set(hc, 'Position',[0.92 0.30 0.02 0.40]);
DV=datevec(SDtime);
printfile=[PTO 'AMSR2_3km_' num2str(DV(1)) '-' num2str(DV(2),'%2.2i') '-' ...
    num2str(DV(3),'%2.2i')];
latest=[PTO 'AMSR2_3km_latest'];
eval(['print ' printfile '.png -f20 -dpng -r' num2str(pres1)]);
eval(['print ' latest '.png -f20 -dpng -r' num2str(pres1)]);
eval(['print ' latest '_sm.png -f20 -dpng -r' num2str(pres2)]);
return