function [SSMI]=SSMINRT_to_PNG_S(SDtime,PTO);
% =======================================================================
%
% AMSR2NRT_to_PNG.m produces a PNG image for the Ross Sea region, from
%   AMSR-2 near-real-time daily images from the EOSDIS Lance server.
%
% Presently set to hard-code data directory for input file, and various
%   other switches
%
%
%  Laurie Padman, ESR (padman@esr.org)
%  Susan Howard,  ESR (showard@esr.org)
%
% =======================================================================
SLAT=71; SLON=0; HEMI='s';            % Polar stereo choices
ax=[-600 500 -1700 -1100];dx=1; nd=1; % Ross Sea continental shelf
lats=[-80:1:-70];                     % values for grid overlay
lons=[-175:5:180];
% Specify where to find *.he5 (HDF5) files
fileloc='./DATA/SSMI_NRT/';
% Set output resolution pres (dpi), gray-scale axis limits (cax) and color
%   for lat/lon grid overlay
pres1=450; pres2=60; % high-res (~3-4 MB) and low-res for web 
cax=[0 100]; gridcol=0.5*[1 1 1];
%========================================================================

DV=datevec(SDtime);
dstr=[num2str(DV(1)) num2str(DV(2),'%2.2i') num2str(DV(3),'%2.2i')];

infile=['nt_' dstr '_f18_nrt_s']; 
printfile=['SSMI_' dstr]; fig=20;

latest=['SSMI_NRT_latest'];
maskfile = fullfile(fileloc,[infile '.bin']);
disp(['Processing ' maskfile]);

fid = fopen(maskfile,'rb');
if(fid==-1);  % No file found for this day
    disp('File not found')
    return
end
hdr1 = fread(fid, [300], 'uchar'); % For files named NT_*
COLS = str2num( setstr(hdr1(7:12)'))
ROWS = str2num( setstr(hdr1(13:18)'))
M = fread(fid, [COLS, ROWS], 'uchar'); % L is an integer representation 
%M = fread(fid, [316,332], 'uint8'); % L is an integer representation 
%                                        of sea ice concentration x 10.
M=double(M)/2.5; M=M'; M=flipud(M); %M(M>100)=NaN;
fclose(fid);
clear X Y
Y=-3950+(25.0/2.0)+25*(0:331);
X=-3950+(25.0/2.0)+25*(0:315);
[X,Y]=meshgrid(X,Y);
[LAT,LON]=mapxy(X,Y,70,0,'s');
[X,Y]=mapll(LAT,LON,SLAT,SLON,'s');

% Return SSMI grid to mains cript for testing
SSMI.X=X; SSMI.Y=Y; SSMI.M=M;

% bathymetry
RT=load('D:\Projects\Antarctic_seaice\Script_data_files\RTOPO2\RTOPO2_ANT.mat');
xg=ax(1):dx:ax(2); yg=ax(3):dx:ax(4);
[xg,yg]=meshgrid(xg,yg);                [rg,cg]=size(xg);
[latg,long]=mapxy(xg,yg,SLAT,SLON,HEMI);
hg=interp2(RT.lon,RT.lat,RT.sbd',long,latg);


figure(fig); clf; colormap(gray(100));
load amsr2_cmap_BGW.mat; colormap(cmap);
pcolor(X,Y,M); shading interp;
hold on
plot_moa(1,'k',SLAT,SLON,HEMI);

% Add lat/lon grid
contour(xg,yg,latg,lats,'color',gridcol,'LineWidth',0.3);
contour(xg,yg,long,lons,'color',gridcol,'LineWidth',0.3);
contour(xg,yg,hg,[-1500 -1000 -500],'b','LineWidth',0.3);
axis('equal'); axis(ax);
caxis(cax); 
set(gca,'LineWidth',1);
title(printfile,'interpreter','none');

% lat/lon labels around edges
% right side
lat1=latg(1,end); lat2=latg(end,end);
loc=find(lats>lat2 & lats<lat1);
for i=1:length(loc);
    LAT=lats(loc(i));
    [dum,ind]=min(abs(latg(:,end)-LAT));
    str=[num2str(-LAT) '^oS'];
    ht=text(ax(2),yg(ind,end),str); hold on
    set(ht,'color','k')
end

% left side
lat1=latg(1,1); lat2=latg(end,1);
loc=find(lats>lat2 & lats<lat1);
for i=1:length(loc);
    LAT=lats(loc(i));
    [dum,ind]=min(abs(latg(:,1)-LAT));
    str=[num2str(-LAT) '^oS'];
    ht=text(ax(1),yg(ind,1),str); hold on
    set(ht,'color','k','HorizontalALignment','right')
end

% bottom
for i=1:length(lons);
    LON=lons(i); ix=1:cg;
    [dum,ind]=min(abs(long(1,:)-LON));
    if(ind<1 | ind>cg); break; end
    if(xg(1,ind)>ax(1) & xg(1,ind)<ax(2));
        str=[num2str(LON) '^o'];
        ht=text(xg(1,ind),ax(3),str); hold on
        set(ht,'color','k','HorizontalALignment','center',...
            'VerticalAlignment','top');
    end
end

set(gca,'XTick',[],'YTick',[]);

% Add float locations
floats=xlsread('D:\Projects\Antarctic_seaice\Script_data_files\Floats\ALAMO_2016\ALAMO_Deployments.xlsx',...
     'A5:H10');
F.lat=floats(:,5); F.lon=floats(:,6); F.id=floats(:,2);
[F.x,F.y]=mapll(F.lat,F.lon,SLAT,SLON,HEMI);
for i=1:length(F.x);
    plot(F.x(i),F.y(i),'o','color','y','LineWidth',1.5,...
        'MarkerFaceColor','r'); hold on
    if(i==1 | i==4)
        ht=text(F.x(i)-10,F.y(i),num2str(F.id(i)),...
            'HorizontalAlignment','right'); hold on
    else
        ht=text(F.x(i)+10,F.y(i),num2str(F.id(i))); hold on
    end
    set(ht,'color','y','Rotation',0,'FontSize',8)
end

hc=colorbar;
set(gca,'Position',[0.10 0.10 0.75 0.80]);
set(hc, 'Position',[0.92 0.30 0.02 0.40]);


% disp([num2str(min(min(M))) ' ' num2str(max(max(M)))]);
% colorbar
eval(['print ' PTO printfile '.png -f20 -dpng -r' num2str(pres1)]);
eval(['print ' PTO latest '.png -f20 -dpng -r' num2str(pres1)]);
eval(['print ' PTO latest '_sm.png -f20 -dpng -r' num2str(pres2)]);
return